/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 03088
 |           ALCOHOL AND DRUG SERVICES STUDY (ADSS), 1996-1999:
 |                            [UNITED STATES]
 |                       (DATASET 0012: COST STUDY)
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 03088-0012-statasetup.do)
 |
 **************************************************************************/

set mem 7m  /* Allocating 7 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "Alcohol and Drug Services Study (ADSS), 1996-1999: [United States], Cost Study"

#delimit ;
label define FACTYPE   1 "HOSPITAL INPATIENT" 2 "RESIDENTIAL"
                       3 "OUTPATIENT METHADONE" 4 "OUTPATIENT NON-METHADONE" ;
label define OWNSHIP   -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PRIVATE, FOR-PROFIT" 2 "PRIVATE, NON-PROFIT"
                       3 "PUBLIC" ;
label define MULTIPLE  0 "SINGLE MODALITY" 1 "MULTIPLE MODALITY" ;
label define STUDY     -99 "INAPPLICABLE" -98 "BLANK/MISSING" 0 "MAIN STUDY"
                       1 "INCENTIVE STUDY" ;
label define NQ3       -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ3       -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define OADMIT    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define NQA       -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQA       -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define BIG_N     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define BIG_N2    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define NQD       -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define NQD2      -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQD       -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQL       -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQL       -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQB       -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQB       -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ55      -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ55      -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define SQ52      -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQI       -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQI       -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQG1      -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQG1      -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQG2      -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQG2      -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQG3      -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQG3      -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQG4      -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQG4      -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQG5      -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQG5      -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQGS      -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQGS      -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NGRPHRS   -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SGRPHRS   -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47A1    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47A1    -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47B1    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47B1    -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47C1    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47C1    -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47D1    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47D1    -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47E1    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47E1    -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47F1    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47F1    -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47G1    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47G1    -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47H1    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47H1    -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ49A     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ49A     -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ49B     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ49B     -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ49C     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ49C     -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ49D     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ49D     -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ49E     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ49E     -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ49F     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ49F     -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ49G     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ49G     -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ49H     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ49H     -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47A4    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47A4    -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47B4    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47B4    -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47C4    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47C4    -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47D4    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47D4    -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47E4    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47E4    -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47F4    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47F4    -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47G4    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47G4    -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47H4    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47H4    -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47A23   -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47A23   -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47B23   -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47B23   -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47C23   -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47C23   -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47D23   -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47D23   -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47E23   -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47E23   -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47F23   -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47F23   -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47G23   -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47G23   -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47H23   -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47H23   -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ49PA    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ49PA    -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ49PB    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ49PB    -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ49PC    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ49PC    -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ49PD    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ49PD    -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ49PE    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ49PE    -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ49PF    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ49PF    -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ49PG    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ49PG    -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ49PH    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ49PH    -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47A4R   -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47A4R   -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47B4R   -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47B4R   -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47C4R   -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47C4R   -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47D4R   -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47D4R   -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47E4R   -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47E4R   -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47F4R   -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47F4R   -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47G4R   -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47G4R   -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ47H4R   -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ47H4R   -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NQ50      -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SQ50      -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define SNB12     -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NC21      -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SNC21     -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NC22      -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SNC22     -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define NC3       -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SC3       -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define ND14      -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SD14      -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define SD7       -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define ND15A     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SD15A     -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define ND15AP    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SD15AP    -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define ND15A_D   -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define ND15A_P   -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define ND15B     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SD15B     -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define ND15BP    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SD15BP    -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define ND15B_D   -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define ND15B_P   -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define ND15C     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SD15C     -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define ND15CP    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SD15CP    -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define ND15C_D   -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define ND15C_P   -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define ND15D     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SD15D     -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define ND15DP    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SD15DP    -99 "INAPPLICABLE" -98 "BLANK/MISSING"
                       1 "PROVIDER ORIGINAL" 2 "PROVIDER DOCUMENTATION"
                       3 "PROVIDER REVISED" 4 "INTERNAL ESTIMATE"
                       5 "EXTERNAL ESTIMATE" ;
label define ND15D_D   -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define ND15D_P   -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define V1K17     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define V1K20     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define V1K23     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N1C26     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N1G26     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define V1K26     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N1C27     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N1G27     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define V1K27     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N1C33     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N1G33     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define V1K33     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N1C34     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N1G34     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define V1K34     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N1C35     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N1G35     -99 "INAPPLICABLE" ;
label define V1K35     -99 "INAPPLICABLE" ;
label define V1C37     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define V1C38     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define V2F9      -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define V2F12     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define U2B22     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define U2D22     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define V2F22     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define U2B23     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define U2D23     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define U2B25     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define U2D25     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define V2F25     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define U2B26     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define U2D26     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define U2B28     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define U2B29     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define U2B30     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define U2B31     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N3N12     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N3N13     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N3N14     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N3N15     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N3N16     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N3N17     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N3N18     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N3N19     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N3N23     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N3N24     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N3N25     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N3N26     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N3N27     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N3N28     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N3N29     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N3N30     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N3B32     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N3N32     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N3N33     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N3N34     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define P3N38     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N3J40     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define P3N40     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N3J42     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define P3N42     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N3J44     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define P3N44     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N3J46     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N4N7      -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define P3N46     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N4B8      -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N4F8      -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N4B9      -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N4F9      -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N4J9      -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N4J12     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N4N12     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N4N17     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N4N18     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N4N19     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N4N20     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N4N21     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N4N22     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N4F24     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N4J24     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N4B27     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N4N27     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N4N30     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N4N31     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N4N32     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N4J36     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N4N36     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N4N38     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N4N42     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define V5F28     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define V5F30     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define V5F32     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N5D36     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define V5F36     -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define ABVISIT   -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define TRT_DUR   -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define ABALOS    -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define ABALOSSD  -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define N         -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;
label define SE        -99 "INAPPLICABLE" -98 "BLANK/MISSING" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace OWNSHIP = . if (OWNSHIP == -98 | OWNSHIP == -99)
replace STUDY = . if (STUDY == -98 | STUDY == -99)
replace NQ3 = . if (NQ3 == -98 | NQ3 == -99)
replace SQ3 = . if (SQ3 == -98 | SQ3 == -99)
replace OADMIT = . if (OADMIT == -98 | OADMIT == -99)
replace NQA = . if (NQA == -98 | NQA == -99)
replace SQA = . if (SQA == -98 | SQA == -99)
replace BIG_N = . if (BIG_N == -98 | BIG_N == -99)
replace BIG_N2 = . if (BIG_N2 == -98 | BIG_N2 == -99)
replace NQD = . if (NQD == -98 | NQD == -99)
replace NQD2 = . if (NQD2 == -98 | NQD2 == -99)
replace SQD = . if (SQD == -98 | SQD == -99)
replace NQL = . if (NQL == -98.00 | NQL == -99.00)
replace SQL = . if (SQL == -98 | SQL == -99)
replace NQB = . if (NQB == -98 | NQB == -99)
replace SQB = . if (SQB == -98 | SQB == -99)
replace NQ55 = . if (NQ55 == -98 | NQ55 == -99)
replace SQ55 = . if (SQ55 == -98 | SQ55 == -99)
replace SQ52 = . if (SQ52 == -98 | SQ52 == -99)
replace NQI = . if (NQI == -98.00 | NQI == -99.00)
replace SQI = . if (SQI == -98 | SQI == -99)
replace NQG1 = . if (NQG1 == -98.0 | NQG1 == -99.0)
replace SQG1 = . if (SQG1 == -98 | SQG1 == -99)
replace NQG2 = . if (NQG2 == -98.0 | NQG2 == -99.0)
replace SQG2 = . if (SQG2 == -98 | SQG2 == -99)
replace NQG3 = . if (NQG3 == -98.0 | NQG3 == -99.0)
replace SQG3 = . if (SQG3 == -98 | SQG3 == -99)
replace NQG4 = . if (NQG4 == -98.0 | NQG4 == -99.0)
replace SQG4 = . if (SQG4 == -98 | SQG4 == -99)
replace NQG5 = . if (NQG5 == -98.00 | NQG5 == -99.00)
replace SQG5 = . if (SQG5 <= -1 )
replace NQGS = . if (NQGS == -98.00 | NQGS == -99.00)
replace SQGS = . if (SQGS <= -1 )
replace NGRPHRS = . if (NGRPHRS == -98.00 | NGRPHRS == -99.00)
replace SGRPHRS = . if (SGRPHRS == -98 | SGRPHRS == -99)
replace NQ47A1 = . if (NQ47A1 == -98 | NQ47A1 == -99)
replace SQ47A1 = . if (SQ47A1 == -98 | SQ47A1 == -99)
replace NQ47B1 = . if (NQ47B1 == -98 | NQ47B1 == -99)
replace SQ47B1 = . if (SQ47B1 == -98 | SQ47B1 == -99)
replace NQ47C1 = . if (NQ47C1 == -98 | NQ47C1 == -99)
replace SQ47C1 = . if (SQ47C1 == -98 | SQ47C1 == -99)
replace NQ47D1 = . if (NQ47D1 == -98 | NQ47D1 == -99)
replace SQ47D1 = . if (SQ47D1 == -98 | SQ47D1 == -99)
replace NQ47E1 = . if (NQ47E1 == -98.0 | NQ47E1 == -99.0)
replace SQ47E1 = . if (SQ47E1 == -98 | SQ47E1 == -99)
replace NQ47F1 = . if (NQ47F1 == -98 | NQ47F1 == -99)
replace SQ47F1 = . if (SQ47F1 == -98 | SQ47F1 == -99)
replace NQ47G1 = . if (NQ47G1 == -98 | NQ47G1 == -99)
replace SQ47G1 = . if (SQ47G1 == -98 | SQ47G1 == -99)
replace NQ47H1 = . if (NQ47H1 == -98.0 | NQ47H1 == -99.0)
replace SQ47H1 = . if (SQ47H1 == -98 | SQ47H1 == -99)
replace NQ49A = . if (NQ49A == -98.00 | NQ49A == -99.00)
replace SQ49A = . if (SQ49A == -98 | SQ49A == -99)
replace NQ49B = . if (NQ49B == -98.00 | NQ49B == -99.00)
replace SQ49B = . if (SQ49B == -98 | SQ49B == -99)
replace NQ49C = . if (NQ49C == -98.00 | NQ49C == -99.00)
replace SQ49C = . if (SQ49C == -98 | SQ49C == -99)
replace NQ49D = . if (NQ49D == -98.00 | NQ49D == -99.00)
replace SQ49D = . if (SQ49D == -98 | SQ49D == -99)
replace NQ49E = . if (NQ49E == -98.00 | NQ49E == -99.00)
replace SQ49E = . if (SQ49E == -98 | SQ49E == -99)
replace NQ49F = . if (NQ49F == -98.00 | NQ49F == -99.00)
replace SQ49F = . if (SQ49F == -98 | SQ49F == -99)
replace NQ49G = . if (NQ49G == -98.00 | NQ49G == -99.00)
replace SQ49G = . if (SQ49G == -98 | SQ49G == -99)
replace NQ49H = . if (NQ49H == -98.00 | NQ49H == -99.00)
replace SQ49H = . if (SQ49H == -98 | SQ49H == -99)
replace NQ47A4 = . if (NQ47A4 == -98.0 | NQ47A4 == -99.0)
replace SQ47A4 = . if (SQ47A4 == -98 | SQ47A4 == -99)
replace NQ47B4 = . if (NQ47B4 == -98.0 | NQ47B4 == -99.0)
replace SQ47B4 = . if (SQ47B4 == -98 | SQ47B4 == -99)
replace NQ47C4 = . if (NQ47C4 == -98.0 | NQ47C4 == -99.0)
replace SQ47C4 = . if (SQ47C4 == -98 | SQ47C4 == -99)
replace NQ47D4 = . if (NQ47D4 == -98.0 | NQ47D4 == -99.0)
replace SQ47D4 = . if (SQ47D4 == -98 | SQ47D4 == -99)
replace NQ47E4 = . if (NQ47E4 == -98.00 | NQ47E4 == -99.00)
replace SQ47E4 = . if (SQ47E4 == -98 | SQ47E4 == -99)
replace NQ47F4 = . if (NQ47F4 == -98.00 | NQ47F4 == -99.00)
replace SQ47F4 = . if (SQ47F4 == -98 | SQ47F4 == -99)
replace NQ47G4 = . if (NQ47G4 == -98.00 | NQ47G4 == -99.00)
replace SQ47G4 = . if (SQ47G4 == -98 | SQ47G4 == -99)
replace NQ47H4 = . if (NQ47H4 == -98.00 | NQ47H4 == -99.00)
replace SQ47H4 = . if (SQ47H4 == -98 | SQ47H4 == -99)
replace NQ47A23 = . if (NQ47A23 == -98 | NQ47A23 == -99)
replace SQ47A23 = . if (SQ47A23 <= -1 )
replace NQ47B23 = . if (NQ47B23 == -98 | NQ47B23 == -99)
replace SQ47B23 = . if (SQ47B23 == -98 | SQ47B23 == -99)
replace NQ47C23 = . if (NQ47C23 == -98 | NQ47C23 == -99)
replace SQ47C23 = . if (SQ47C23 == -98 | SQ47C23 == -99)
replace NQ47D23 = . if (NQ47D23 == -98 | NQ47D23 == -99)
replace SQ47D23 = . if (SQ47D23 == -98 | SQ47D23 == -99)
replace NQ47E23 = . if (NQ47E23 == -98 | NQ47E23 == -99)
replace SQ47E23 = . if (SQ47E23 == -98 | SQ47E23 == -99)
replace NQ47F23 = . if (NQ47F23 == -98 | NQ47F23 == -99)
replace SQ47F23 = . if (SQ47F23 == -98 | SQ47F23 == -99)
replace NQ47G23 = . if (NQ47G23 == -98 | NQ47G23 == -99)
replace SQ47G23 = . if (SQ47G23 == -98 | SQ47G23 == -99)
replace NQ47H23 = . if (NQ47H23 == -98 | NQ47H23 == -99)
replace SQ47H23 = . if (SQ47H23 == -98 | SQ47H23 == -99)
replace NQ49PA = . if (NQ49PA == -98.00 | NQ49PA == -99.00)
replace SQ49PA = . if (SQ49PA == -98 | SQ49PA == -99)
replace NQ49PB = . if (NQ49PB == -98.00 | NQ49PB == -99.00)
replace SQ49PB = . if (SQ49PB == -98 | SQ49PB == -99)
replace NQ49PC = . if (NQ49PC == -98.00 | NQ49PC == -99.00)
replace SQ49PC = . if (SQ49PC == -98 | SQ49PC == -99)
replace NQ49PD = . if (NQ49PD == -98.00 | NQ49PD == -99.00)
replace SQ49PD = . if (SQ49PD == -98 | SQ49PD == -99)
replace NQ49PE = . if (NQ49PE == -98.00 | NQ49PE == -99.00)
replace SQ49PE = . if (SQ49PE == -98 | SQ49PE == -99)
replace NQ49PF = . if (NQ49PF == -98.00 | NQ49PF == -99.00)
replace SQ49PF = . if (SQ49PF == -98 | SQ49PF == -99)
replace NQ49PG = . if (NQ49PG == -98.00 | NQ49PG == -99.00)
replace SQ49PG = . if (SQ49PG == -98 | SQ49PG == -99)
replace NQ49PH = . if (NQ49PH == -98.00 | NQ49PH == -99.00)
replace SQ49PH = . if (SQ49PH == -98 | SQ49PH == -99)
replace NQ47A4R = . if (NQ47A4R == -98.00 | NQ47A4R == -99.00)
replace SQ47A4R = . if (SQ47A4R == -98 | SQ47A4R == -99)
replace NQ47B4R = . if (NQ47B4R == -98.00 | NQ47B4R == -99.00)
replace SQ47B4R = . if (SQ47B4R == -98 | SQ47B4R == -99)
replace NQ47C4R = . if (NQ47C4R == -98.00 | NQ47C4R == -99.00)
replace SQ47C4R = . if (SQ47C4R == -98 | SQ47C4R == -99)
replace NQ47D4R = . if (NQ47D4R == -98.00 | NQ47D4R == -99.00)
replace SQ47D4R = . if (SQ47D4R == -98 | SQ47D4R == -99)
replace NQ47E4R = . if (NQ47E4R == -98.00 | NQ47E4R == -99.00)
replace SQ47E4R = . if (SQ47E4R == -98 | SQ47E4R == -99)
replace NQ47F4R = . if (NQ47F4R == -98.00 | NQ47F4R == -99.00)
replace SQ47F4R = . if (SQ47F4R == -98 | SQ47F4R == -99)
replace NQ47G4R = . if (NQ47G4R == -98.00 | NQ47G4R == -99.00)
replace SQ47G4R = . if (SQ47G4R == -98 | SQ47G4R == -99)
replace NQ47H4R = . if (NQ47H4R == -98.00 | NQ47H4R == -99.00)
replace SQ47H4R = . if (SQ47H4R == -98 | SQ47H4R == -99)
replace NQ50 = . if (NQ50 == -98.0000 | NQ50 == -99.0000)
replace SQ50 = . if (SQ50 == -98 | SQ50 == -99)
replace SNB12 = . if (SNB12 == -98 | SNB12 == -99)
replace NC21 = . if (NC21 == -98 | NC21 == -99)
replace SNC21 = . if (SNC21 == -98 | SNC21 == -99)
replace NC22 = . if (NC22 == -98 | NC22 == -99)
replace SNC22 = . if (SNC22 == -98 | SNC22 == -99)
replace NC3 = . if (NC3 == -98.00 | NC3 == -99.00)
replace SC3 = . if (SC3 == -98 | SC3 == -99)
replace ND14 = . if (ND14 == -98 | ND14 == -99)
replace SD14 = . if (SD14 == -98 | SD14 == -99)
replace SD7 = . if (SD7 == -98 | SD7 == -99)
replace ND15A = . if (ND15A == -98.0 | ND15A == -99.0)
replace SD15A = . if (SD15A == -98 | SD15A == -99)
replace ND15AP = . if (ND15AP == -98.000 | ND15AP == -99.000)
replace SD15AP = . if (SD15AP == -98 | SD15AP == -99)
replace ND15A_D = . if (ND15A_D == -98 | ND15A_D == -99)
replace ND15A_P = . if (ND15A_P == -98.0000 | ND15A_P == -99.0000)
replace ND15B = . if (ND15B == -98 | ND15B == -99)
replace SD15B = . if (SD15B == -98 | SD15B == -99)
replace ND15BP = . if (ND15BP == -98.000 | ND15BP == -99.000)
replace SD15BP = . if (SD15BP == -98 | SD15BP == -99)
replace ND15B_D = . if (ND15B_D == -98.0 | ND15B_D == -99.0)
replace ND15B_P = . if (ND15B_P == -98.000 | ND15B_P == -99.000)
replace ND15C = . if (ND15C == -98.0 | ND15C == -99.0)
replace SD15C = . if (SD15C == -98 | SD15C == -99)
replace ND15CP = . if (ND15CP == -98.0000 | ND15CP == -99.0000)
replace SD15CP = . if (SD15CP == -98 | SD15CP == -99)
replace ND15C_D = . if (ND15C_D == -98.0 | ND15C_D == -99.0)
replace ND15C_P = . if (ND15C_P == -98.0000 | ND15C_P == -99.0000)
replace ND15D = . if (ND15D == -98 | ND15D == -99)
replace SD15D = . if (SD15D == -98 | SD15D == -99)
replace ND15DP = . if (ND15DP == -98.0000 | ND15DP == -99.0000)
replace SD15DP = . if (SD15DP == -98 | SD15DP == -99)
replace ND15D_D = . if (ND15D_D == -98.0 | ND15D_D == -99.0)
replace ND15D_P = . if (ND15D_P == -98.0000 | ND15D_P == -99.0000)
replace V1K17 = . if (V1K17 == -98.0000 | V1K17 == -99.0000)
replace V1K20 = . if (V1K20 == -98.0000 | V1K20 == -99.0000)
replace V1K23 = . if (V1K23 == -98.0000 | V1K23 == -99.0000)
replace N1C26 = . if (N1C26 == -98 | N1C26 == -99)
replace N1G26 = . if (N1G26 == -98.0 | N1G26 == -99.0)
replace V1K26 = . if (V1K26 == -98.0000 | V1K26 == -99.0000)
replace N1C27 = . if (N1C27 == -98 | N1C27 == -99)
replace N1G27 = . if (N1G27 == -98 | N1G27 == -99)
replace V1K27 = . if (V1K27 == -98.0000 | V1K27 == -99.0000)
replace N1C33 = . if (N1C33 == -98.0000 | N1C33 == -99.0000)
replace N1G33 = . if (N1G33 == -98.0000 | N1G33 == -99.0000)
replace V1K33 = . if (V1K33 == -98.0000 | V1K33 == -99.0000)
replace N1C34 = . if (N1C34 == -98.0000 | N1C34 == -99.0000)
replace N1G34 = . if (N1G34 == -98.0000 | N1G34 == -99.0000)
replace V1K34 = . if (V1K34 == -98.0000 | V1K34 == -99.0000)
replace N1C35 = . if (N1C35 == -98.0000 | N1C35 == -99.0000)
replace N1G35 = . if (N1G35 == -98.00 | N1G35 == -99.00)
replace V1K35 = . if (V1K35 == -98.00 | V1K35 == -99.00)
replace V1C37 = . if (V1C37 == -98.0000 | V1C37 == -99.0000)
replace V1C38 = . if (V1C38 == -98.0000 | V1C38 == -99.0000)
replace V2F9 = . if (V2F9 == -98.0000 | V2F9 == -99.0000)
replace V2F12 = . if (V2F12 == -98.0000 | V2F12 == -99.0000)
replace U2B22 = . if (U2B22 == -98.0 | U2B22 == -99.0)
replace U2D22 = . if (U2D22 == -98 | U2D22 == -99)
replace V2F22 = . if (V2F22 == -98.0000 | V2F22 == -99.0000)
replace U2B23 = . if (U2B23 == -98.0000 | U2B23 == -99.0000)
replace U2D23 = . if (U2D23 == -98.0000 | U2D23 == -99.0000)
replace U2B25 = . if (U2B25 == -98.0 | U2B25 == -99.0)
replace U2D25 = . if (U2D25 == -98 | U2D25 == -99)
replace V2F25 = . if (V2F25 == -98.0000 | V2F25 == -99.0000)
replace U2B26 = . if (U2B26 == -98.0000 | U2B26 == -99.0000)
replace U2D26 = . if (U2D26 == -98.0000 | U2D26 == -99.0000)
replace U2B28 = . if (U2B28 == -98.0 | U2B28 == -99.0)
replace U2B29 = . if (U2B29 == -98.0000 | U2B29 == -99.0000)
replace U2B30 = . if (U2B30 == -98.0000 | U2B30 == -99.0000)
replace U2B31 = . if (U2B31 == -98.00 | U2B31 == -99.00)
replace N3N12 = . if (N3N12 == -98.0 | N3N12 == -99.0)
replace N3N13 = . if (N3N13 == -98.0 | N3N13 == -99.0)
replace N3N14 = . if (N3N14 == -98.0 | N3N14 == -99.0)
replace N3N15 = . if (N3N15 == -98.0 | N3N15 == -99.0)
replace N3N16 = . if (N3N16 == -98.0 | N3N16 == -99.0)
replace N3N17 = . if (N3N17 == -98.0 | N3N17 == -99.0)
replace N3N18 = . if (N3N18 == -98.0 | N3N18 == -99.0)
replace N3N19 = . if (N3N19 == -98.0 | N3N19 == -99.0)
replace N3N23 = . if (N3N23 == -98.0 | N3N23 == -99.0)
replace N3N24 = . if (N3N24 == -98.0 | N3N24 == -99.0)
replace N3N25 = . if (N3N25 == -98.0 | N3N25 == -99.0)
replace N3N26 = . if (N3N26 == -98.0 | N3N26 == -99.0)
replace N3N27 = . if (N3N27 == -98.0 | N3N27 == -99.0)
replace N3N28 = . if (N3N28 == -98.0 | N3N28 == -99.0)
replace N3N29 = . if (N3N29 == -98.0 | N3N29 == -99.0)
replace N3N30 = . if (N3N30 == -98.0 | N3N30 == -99.0)
replace N3B32 = . if (N3B32 == -98.00 | N3B32 == -99.00)
replace N3N32 = . if (N3N32 == -98.0 | N3N32 == -99.0)
replace N3N33 = . if (N3N33 == -98.0 | N3N33 == -99.0)
replace N3N34 = . if (N3N34 == -98.0 | N3N34 == -99.0)
replace P3N38 = . if (P3N38 == -98.0000 | P3N38 == -99.0000)
replace N3J40 = . if (N3J40 == -98.0 | N3J40 == -99.0)
replace P3N40 = . if (P3N40 == -98.0000 | P3N40 == -99.0000)
replace N3J42 = . if (N3J42 == -98.0 | N3J42 == -99.0)
replace P3N42 = . if (P3N42 == -98.0000 | P3N42 == -99.0000)
replace N3J44 = . if (N3J44 == -98.0 | N3J44 == -99.0)
replace P3N44 = . if (P3N44 == -98.0000 | P3N44 == -99.0000)
replace N3J46 = . if (N3J46 == -98.0 | N3J46 == -99.0)
replace N4N7 = . if (N4N7 == -98.0 | N4N7 == -99.0)
replace P3N46 = . if (P3N46 == -98.0000 | P3N46 == -99.0000)
replace N4B8 = . if (N4B8 == -98.0000 | N4B8 == -99.0000)
replace N4F8 = . if (N4F8 == -98.0 | N4F8 == -99.0)
replace N4B9 = . if (N4B9 == -98.0000 | N4B9 == -99.0000)
replace N4F9 = . if (N4F9 == -98.0 | N4F9 == -99.0)
replace N4J9 = . if (N4J9 == -98.0000 | N4J9 == -99.0000)
replace N4J12 = . if (N4J12 == -98.0000 | N4J12 == -99.0000)
replace N4N12 = . if (N4N12 == -98.0 | N4N12 == -99.0)
replace N4N17 = . if (N4N17 == -98.00 | N4N17 == -99.00)
replace N4N18 = . if (N4N18 == -98.00 | N4N18 == -99.00)
replace N4N19 = . if (N4N19 == -98.00 | N4N19 == -99.00)
replace N4N20 = . if (N4N20 == -98.000 | N4N20 == -99.000)
replace N4N21 = . if (N4N21 == -98.0000 | N4N21 == -99.0000)
replace N4N22 = . if (N4N22 == -98.0000 | N4N22 == -99.0000)
replace N4F24 = . if (N4F24 == -98.0000 | N4F24 == -99.0000)
replace N4J24 = . if (N4J24 == -98.0000 | N4J24 == -99.0000)
replace N4B27 = . if (N4B27 == -98.0000 | N4B27 == -99.0000)
replace N4N27 = . if (N4N27 == -98.0 | N4N27 == -99.0)
replace N4N30 = . if (N4N30 == -98.0 | N4N30 == -99.0)
replace N4N31 = . if (N4N31 == -98.0000 | N4N31 == -99.0000)
replace N4N32 = . if (N4N32 == -98.0000 | N4N32 == -99.0000)
replace N4J36 = . if (N4J36 == -98.0 | N4J36 == -99.0)
replace N4N36 = . if (N4N36 == -98.0 | N4N36 == -99.0)
replace N4N38 = . if (N4N38 == -98.0 | N4N38 == -99.0)
replace N4N42 = . if (N4N42 == -98.0 | N4N42 == -99.0)
replace V5F28 = . if (V5F28 == -98.0000 | V5F28 == -99.0000)
replace V5F30 = . if (V5F30 == -98.0000 | V5F30 == -99.0000)
replace V5F32 = . if (V5F32 == -98.0000 | V5F32 == -99.0000)
replace N5D36 = . if (N5D36 == -98.0000 | N5D36 == -99.0000)
replace V5F36 = . if (V5F36 == -98.0000 | V5F36 == -99.0000)
replace ABVISIT = . if (ABVISIT == -98.0000 | ABVISIT == -99.0000)
replace TRT_DUR = . if (TRT_DUR == -98 | TRT_DUR == -99)
replace ABALOS = . if (ABALOS == -98.0 | ABALOS == -99.0)
replace ABALOSSD = . if (ABALOSSD == -98.0 | ABALOSSD == -99.0)
replace N = . if (N == -98 | N == -99)
replace SE = . if (SE == -98.0 | SE == -99.0)


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

